@@ -2,7 +2,7 @@
  *
  *  Connection Manager
  *
- *  Copyright (C) 2007-2008  Intel Corporation. All rights reserved.
+ *  Copyright (C) 2007-2009  Intel Corporation. All rights reserved.
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License version 2 as
@@ -27,6 +27,9 @@
 #include <string.h>
 #include <dbus/dbus.h>
 
+#include <glib.h>
+
+#define CONNMAN_API_SUBJECT_TO_CHANGE
 #include <connman/log.h>
 #include <connman/dbus.h>
 
@@ -42,7 +45,7 @@
 struct supplicant_task {
 	int ifindex;
 	gchar *ifname;
-	struct connman_element *element;
+	struct connman_device *device;
 	struct supplicant_callback *callback;
 	gchar *path;
 	gboolean created;
@@ -655,6 +658,11 @@ static void extract_capabilites(struct supplicant_network *network,
 {
 	dbus_message_iter_get_basic(value, &network->capabilities);
 
+	if (network->capabilities & IEEE80211_CAP_ESS)
+		network->adhoc = FALSE;
+	else if (network->capabilities & IEEE80211_CAP_IBSS)
+		network->adhoc = TRUE;
+
 	if (network->capabilities & IEEE80211_CAP_PRIVACY)
 		network->has_wep = TRUE;
 }
@@ -727,7 +735,7 @@ static void properties_reply(DBusPendingCall *call, void *user_data)
 	}
 
 	if (task->callback && task->callback->scan_result)
-		task->callback->scan_result(task->element, network);
+		task->callback->scan_result(task->device, network);
 
 	g_free(network->identifier);
 	g_free(network->ssid);
@@ -790,7 +798,7 @@ static void scan_results_reply(DBusPendingCall *call, void *user_data)
 	}
 
 	if (task->callback && task->callback->clear_results)
-			task->callback->clear_results(task->element);
+			task->callback->clear_results(task->device);
 
 	for (i = 0; i < num_results; i++)
 		get_network_properties(task, results[i]);
@@ -866,7 +874,7 @@ static void state_change(struct supplicant_task *task, DBusMessage *msg)
 		task->state = STATE_DISCONNECTED;
 
 	if (task->callback && task->callback->state_change)
-		task->callback->state_change(task->element, task->state);
+		task->callback->state_change(task->device, task->state);
 
 	switch (task->state) {
 	case STATE_COMPLETED:
@@ -960,21 +968,21 @@ static int remove_filter(struct supplicant_task *task)
 	return 0;
 }
 
-int __supplicant_start(struct connman_element *element,
+int __supplicant_start(struct connman_device *device,
 					struct supplicant_callback *callback)
 {
 	struct supplicant_task *task;
 	int err;
 
-	DBG("element %p name %s", element, element->name);
+	DBG("device %p", device);
 
 	task = g_try_new0(struct supplicant_task, 1);
 	if (task == NULL)
 		return -ENOMEM;
 
-	task->ifindex = element->index;
-	task->ifname = inet_index2name(element->index);
-	task->element = element;
+	task->ifindex = connman_device_get_index(device);
+	task->ifname = inet_index2name(task->ifindex);
+	task->device = device;
 	task->callback = callback;
 
 	if (task->ifname == NULL) {
@@ -1003,13 +1011,14 @@ int __supplicant_start(struct connman_element *element,
 	return 0;
 }
 
-int __supplicant_stop(struct connman_element *element)
+int __supplicant_stop(struct connman_device *device)
 {
+	int index = connman_device_get_index(device);
 	struct supplicant_task *task;
 
-	DBG("element %p name %s", element, element->name);
+	DBG("device %p", device);
 
-	task = find_task_by_index(element->index);
+	task = find_task_by_index(index);
 	if (task == NULL)
 		return -ENODEV;
 
@@ -1030,14 +1039,15 @@ int __supplicant_stop(struct connman_element *element)
 	return 0;
 }
 
-int __supplicant_scan(struct connman_element *element)
+int __supplicant_scan(struct connman_device *device)
 {
+	int index = connman_device_get_index(device);
 	struct supplicant_task *task;
 	int err;
 
-	DBG("element %p name %s", element, element->name);
+	DBG("device %p", device);
 
-	task = find_task_by_index(element->index);
+	task = find_task_by_index(index);
 	if (task == NULL)
 		return -ENODEV;
 
@@ -1064,7 +1074,7 @@ int __supplicant_connect(struct connman_element *element,
 {
 	struct supplicant_task *task;
 
-	DBG("element %p name %s", element, element->name);
+	DBG("element %p", element);
 
 	task = find_task_by_index(element->index);
 	if (task == NULL)
@@ -1086,7 +1096,7 @@ int __supplicant_disconnect(struct connman_element *element)
 {
 	struct supplicant_task *task;
 
-	DBG("element %p name %s", element, element->name);
+	DBG("element %p", element);
 
 	task = find_task_by_index(element->index);
 	if (task == NULL)
@@ -1107,7 +1117,7 @@ void __supplicant_activate(DBusConnection *conn)
 
 	message = dbus_message_new_method_call(SUPPLICANT_NAME, "/",
 				DBUS_INTERFACE_INTROSPECTABLE, "Introspect");
-        if (message == NULL)
+	if (message == NULL)
 		return;
 
 	dbus_message_set_no_reply(message, TRUE);
