@@ -2,7 +2,7 @@
  *
  *  Connection Manager
  *
- *  Copyright (C) 2007-2008  Intel Corporation. All rights reserved.
+ *  Copyright (C) 2007-2009  Intel Corporation. All rights reserved.
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License version 2 as
@@ -150,20 +150,23 @@ int main(int argc, char *argv[])
 		}
 	}
 
-	__connman_storage_init();
+	__connman_dbus_init(conn);
 
+	__connman_storage_init();
 	__connman_element_init(conn, option_device);
 
 	__connman_agent_init(conn);
-
 	__connman_manager_init(conn, option_compat);
-
 	__connman_profile_init(conn);
 
+	__connman_resolver_init();
 	__connman_rtnl_init();
+	__connman_udev_init();
 
 	__connman_plugin_init();
 
+	__connman_element_start();
+
 	g_free(option_device);
 
 	memset(&sa, 0, sizeof(sa));
@@ -173,20 +176,23 @@ int main(int argc, char *argv[])
 
 	g_main_loop_run(main_loop);
 
+	__connman_element_stop();
+
 	__connman_plugin_cleanup();
 
+	__connman_udev_cleanup();
 	__connman_rtnl_cleanup();
+	__connman_resolver_cleanup();
 
 	__connman_profile_cleanup();
-
 	__connman_manager_cleanup();
-
 	__connman_agent_cleanup();
 
 	__connman_element_cleanup();
-
 	__connman_storage_cleanup();
 
+	__connman_dbus_cleanup();
+
 selftest:
 	__connman_log_cleanup();
 
